@@ -1,19 +1,21 @@
 # -*- coding: utf8 - *-
-"""
-    tmuxp.server
-    ~~~~~~~~~~~~
+"""Pythonization of the :ref:`tmux(1)` server.
 
-    tmuxp helps you manage tmux workspaces.
+tmuxp.server
+~~~~~~~~~~~~
+
+tmuxp helps you manage tmux workspaces.
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
 
-    :copyright: Copyright 2013 Tony Narlock.
-    :license: BSD, see LICENSE for details
 """
 from __future__ import absolute_import, division, print_function, with_statement
 
 import os
 from .util import tmux, TmuxRelationalObject
 from .session import Session
-from . import formats
+from . import formats, exc
 import logging
 
 logger = logging.getLogger(__name__)
@@ -21,8 +23,7 @@ logger = logging.getLogger(__name__)
 
 class Server(TmuxRelationalObject):
 
-    '''
-    The :term:`tmux(1)` server. Container for:
+    """The :term:`tmux(1)` server.
 
     - :attr:`Server._sessions` [:class:`Session`, ...]
 
@@ -34,12 +35,18 @@ class Server(TmuxRelationalObject):
 
     When instantiated, provides the ``t`` global. stores information on live,
     running tmux server.
-    '''
 
+    """
+
+    #: ``[-L socket-name]``
     socket_name = None
+    #: ``[-S socket-path]``
     socket_path = None
+    #: ``[-f file]``
     config_file = None
+    #: ``-2`` or ``-8``
     colors = None
+    #: unique child ID key
     childIdAttribute = 'session_id'
 
     def __init__(
@@ -66,6 +73,12 @@ class Server(TmuxRelationalObject):
             self.colors = colors
 
     def tmux(self, *args, **kwargs):
+        """Return :class:`util.tmux` send tmux commands with sockets, colors.
+
+        :rtype: :class:`util.tmux`
+
+        """
+
         args = list(args)
         if self.socket_name:
             args.insert(0, '-L{}'.format(self.socket_name))
@@ -84,11 +97,14 @@ class Server(TmuxRelationalObject):
         return tmux(*args, **kwargs)
 
     def __list_sessions(self):
-        '''
-        compatibility wrapping for ``$ tmux list-sessions``.
+        """Return list of ``$ tmux(1) list-sessions`` stdout.
 
-        :rtype: stdout or stderr of tmux proc
-        '''
+        The :py:obj:`list` is derived from ``stdout`` in :class:`util.tmux`
+        which wraps :py:meth:`Subprocess.Popen`.
+
+        :rtype: list
+
+        """
         sformats = formats.SESSION_FORMATS
         tmux_formats = ['#{%s}' % f for f in sformats]
 
@@ -135,27 +151,40 @@ class Server(TmuxRelationalObject):
 
     @property
     def _sessions(self):
+        """Return list of the server's sessions as :py:obj:`dict`.
+
+        :rtype: list
+
+        """
+
         return self._list_sessions()
 
     def list_sessions(self):
-        '''
-        Return a list of :class:`Session` from the ``tmux(1)`` session.
+        """Return list of :class:`Session` from the ``tmux(1)`` session.
 
         :rtype: :py:obj:`list` of :class:`Session`
-        '''
+
+        """
         return [
             Session(server=self, **s) for s in self._sessions
         ]
 
     @property
     def sessions(self):
+        """Return a :py:obj:`list` of the server's :class:`Session` objects."""
         return self.list_sessions()
+    #: Alias of :attr:`sessions`.
     children = sessions
 
     def __list_windows(self):
-        '''
-        Return dict of ``tmux(1) list-windows`` values.
-        '''
+        """Return list of ``$ tmux(1) list-windows`` stdout.
+
+        The :py:obj:`list` is derived from ``stdout`` in :class:`util.tmux`
+        which wraps :py:meth:`Subprocess.Popen`.
+
+        :rtype: list
+
+        """
 
         wformats = ['session_name', 'session_id'] + formats.WINDOW_FORMATS
         tmux_formats = ['#{%s}' % format for format in wformats]
@@ -172,8 +201,7 @@ class Server(TmuxRelationalObject):
         return windows.stdout
 
     def _list_windows(self):
-        ''' take the outpout of _list_windows from shell and put it into
-        a list of dicts'''
+        """Return list of dicts filtered from :meth:`__list_windows`."""
 
         wformats = ['session_name', 'session_id'] + formats.WINDOW_FORMATS
 
@@ -202,21 +230,30 @@ class Server(TmuxRelationalObject):
         return self._windows
 
     def _update_windows(self):
+        """Update internal window data and return ``self`` for chainability.
+
+        :rtype: :class:`Server`
+
+        """
         self._list_windows()
         return self
 
     def __list_panes(self):
-        '''Return list of :class:`Pane` for the window.
+        """Return list of ``$ tmux(1) list-panes`` stdout.
 
-        :rtype: list of :class:`Pane`
-        '''
+        The :py:obj:`list` is derived from ``stdout`` in :class:`util.tmux`
+        which wraps :py:meth:`Subprocess.Popen`.
+
+
+        :rtype: list
+
+        """
         pformats = ['session_name', 'session_id',
                     'window_index', 'window_id', 'window_name'] + formats.PANE_FORMATS
         tmux_formats = ['#{%s}\t' % f for f in pformats]
 
         panes = self.tmux(
             'list-panes',
-            #'-t%s:%s' % (self.get('session_name'), self.get('window_id')),
             '-a',
             '-F%s' % ''.join(tmux_formats),     # output
         )
@@ -227,8 +264,7 @@ class Server(TmuxRelationalObject):
         return panes.stdout
 
     def _list_panes(self):
-        ''' take the outpout of _list_panes from shell and put it into
-        a list of dicts'''
+        """Return list of dicts filtered from :meth:`__list_panes`."""
 
         pformats = ['session_name', 'session_id',
                     'window_index', 'window_id', 'window_name'] + formats.PANE_FORMATS
@@ -253,87 +289,22 @@ class Server(TmuxRelationalObject):
         return self._panes
 
     def _update_panes(self):
+        """Update internal pane data and return ``self`` for chainability.
+
+        :rtype: :class:`Server`
+
+        """
         self._list_panes()
         return self
 
-    def list_clients(self):
-        '''
-        Return a list of :class:`client` from tmux server.
-
-        ``$ tmux list-clients``
-        '''
-        cformats = formats.CLIENT_FORMATS
-        tmux_formats = ['#{%s}' % format for format in cformats]
-        # import ipdb
-        # ipdb.set_trace()
-        clients = self.tmux(
-            'list-clients',
-            '-F%s' % '\t'.join(tmux_formats),   # output
-        ).stdout
-
-        # combine format keys with values returned from ``tmux list-windows``
-        clients = [dict(zip(
-            cformats, client.split('\t'))) for client in clients]
-
-        # clear up empty dict
-        new_clients = [
-            dict((k, v) for k, v in client.items() if v) for client in clients
-        ]
-
-        if not self._clients:
-            for client in new_clients:
-                logger.debug('adding client_tty %s' % (client['client_tty']))
-                self._clients.append(client)
-            return self._clients
-
-        new = {client['client_tty']: client for client in new_clients}
-        old = {client.get('client_tty'): client for client in self._clients}
-
-        created = set(new.keys()) - set(old.keys())
-        deleted = set(old.keys()) - set(new.keys())
-        intersect = set(new.keys()).intersection(set(old.keys()))
-
-        diff = {id: dict(set(new[id].items()) - set(old[id].items()))
-                for id in intersect}
-
-        logger.debug(
-            "syncing clients"
-            "\n\tdiff: %s\n"
-            "\tcreated: %s\n"
-            "\tdeleted: %s\n"
-            "\tintersect: %s" % (diff, created, deleted, intersect)
-        )
-
-        for s in self._clients:
-            # remove client objects if deleted or out of client
-            if s.get('client_tty') in deleted:
-                logger.debug("removing %s" % s)
-                self._clients.remove(s)
-
-            if s.get('client_tty') in intersect:
-                logger.debug('updating client_tty %s' % (s.get('client_tty')))
-                s.update(diff[s.get('client_tty')])
-
-        # create client objects for non-existant client_tty's
-        for client in [new[client_tty] for client_tty in created]:
-            logger.debug('new client %s' % client['client_tty'])
-            self._clients.append(client)
-
-        return self._clients
-
-    def has_clients(self):
-        # are any clients connected to tmux
-        proc = self.tmux('list-clients')
-
-        if proc.stderr:
-            raise Exception(proc.stderr)
-
     def attached_sessions(self):
-        '''
-            Returns active :class:`Session` object
+        """Return active :class:`Session` object.
 
-            This will not work where multiple tmux sessions are attached.
-        '''
+        This will not work where multiple tmux sessions are attached.
+
+        :rtype: :class:`Server`
+
+        """
 
         sessions = self._sessions
         attached_sessions = list()
@@ -351,13 +322,12 @@ class Server(TmuxRelationalObject):
         return attached_sessions or None
 
     def has_session(self, target_session):
-        '''
-        ``$ tmux has-session``
+        """Return True if session exists. ``$ tmux has-session``.
 
         :param: target_session: str of session name.
+        :rtype: bool
 
-        returns True if session exists.
-        '''
+        """
 
         proc = self.tmux('has-session', '-t%s' % target_session)
 
@@ -369,18 +339,18 @@ class Server(TmuxRelationalObject):
             return True
 
     def kill_server(self):
-        '''
-        ``$ tmux kill-server``
-        '''
+        """``$ tmux kill-server``."""
         self.tmux('kill-server')
 
     def kill_session(self, target_session=None):
-        '''
-        ``$ tmux kill-session``
+        """Kill the tmux session with ``$ tmux kill-session``, return ``self``.
 
-        :param: target_session: str. note this accepts fnmatch(3). 'asdf' will
-                                kill asdfasd
-        '''
+        :param: target_session: str. note this accepts ``fnmatch(3)``. 'asdf'
+            will kill 'asdfasd'.
+
+        :rtype: :class:`Server`
+
+        """
         proc = self.tmux('kill-session', '-t%s' % target_session)
 
         if proc.stderr:
@@ -389,11 +359,12 @@ class Server(TmuxRelationalObject):
         return self
 
     def switch_client(self, target_session):
-        '''
-        ``$ tmux switch-client``
+        """``$ tmux switch-client``.
 
         :param: target_session: str. name of the session. fnmatch(3) works.
-        '''
+
+        """
+
         # tmux('switch-client', '-t', target_session)
         proc = self.tmux('switch-client', '-t%s' % target_session)
 
@@ -401,11 +372,11 @@ class Server(TmuxRelationalObject):
             raise Exception(proc.stderr)
 
     def attach_session(self, target_session=None):
-        '''
-        ``$ tmux attach-session`` aka alias: ``$ tmux attach``
+        """``$ tmux attach-session`` aka alias: ``$ tmux attach``.
 
         :param: target_session: str. name of the session. fnmatch(3) works.
-        '''
+
+        """
         # tmux('switch-client', '-t', target_session)
         tmux_args = tuple()
         if target_session:
@@ -422,10 +393,7 @@ class Server(TmuxRelationalObject):
                     attach=False,
                     *args,
                     **kwargs):
-        '''
-        ``$ tmux new-session``
-
-        Returns :class:`Session`
+        """Return :class:`Session` from  ``$ tmux new-session``.
 
         Uses ``-P`` flag to print session info, ``-F`` for return formatting
         returns new Session object.
@@ -452,14 +420,16 @@ class Server(TmuxRelationalObject):
         :param kill_session: Kill current session if ``$ tmux has-session``
                              Useful for testing workspaces.
         :type kill_session: bool
-        '''
+        :rtype: :class:`Session`
+
+        """
 
         if self.has_session(session_name):
             if kill_session:
                 self.tmux('kill-session', '-t%s' % session_name)
                 logger.info('session %s exists. killed it.' % session_name)
             else:
-                raise TmuxSessionExists(
+                raise exc.TmuxSessionExists(
                     'Session named %s exists' % session_name
                 )
 
